Welcome to ClientVPS Mirrors

Help for package chisq.posthoc.test
Type: Package
Title: A Post Hoc Analysis for Pearson's Chi-Squared Test for Count Data
Version: 0.1.2
Description: Perform post hoc analysis based on residuals of Pearson's Chi-squared Test for Count Data based on T. Mark Beasley & Randall E. Schumacker (1995) <doi:10.1080/00220973.1995.9943797>.
License: GPL-3
URL: http://chisq-posthoc-test.ebbert.nrw/
BugReports: https://github.com/ebbertd/chisq.posthoc.test/issues
Suggests: knitr, testthat
VignetteBuilder: knitr
Encoding: UTF-8
LazyData: true
RoxygenNote: 6.1.1
NeedsCompilation: no
Packaged: 2019-10-21 15:13:48 UTC; ebbertd
Author: Daniel Ebbert ORCID iD [cre, aut]
Maintainer: Daniel Ebbert <daniel.ebbert@uni-muenster.de>
Repository: CRAN
Date/Publication: 2019-10-25 08:00:06 UTC

Perform post hoc analysis based on residuals of Pearson's Chi-squared Test for Count Data.

Description

Perform post hoc analysis based on residuals of Pearson's Chi-squared Test for Count Data.

Usage

chisq.posthoc.test(x, method = "bonferroni", round = 6, ...)

Arguments

x

A matrix passed on to the chisq.test function.

method

The p adjustment method to be used. This is passed on to the p.adjust function.

round

Number of digits to round the p.value to. Defaults to 6.

...

Additional arguments passed on to the chisq.test function.

Value

A table with the adjusted p value for each x y combination.

References

Agresti, A. (2007). An Introduction to Categorical Data Analysis, 2nd ed. New York: John Wiley & Sons. Page 38.

Beasley, T. M., & Schumacker, R. E. (1995). Multiple Regression Approach to Analyzing Contingency Tables: Post Hoc and Planned Comparison Procedures. The Journal of Experimental Education, 64(1), 79–93.

Examples

# Data from Agresti(2007) p.39
M <- as.table(rbind(c(762, 327, 468), c(484, 239, 477)))
dimnames(M) <- list(gender = c("F", "M"),
                   party = c("Democrat","Independent", "Republican"))

# Pass data matrix to chisq.posthoc.test function
chisq.posthoc.test(M)

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.